@@ -1,7 +1,8 @@
 model.elements <- function(model, factorNames, itemtype, nfactNames, nfact, J, K, fulldata,
                            itemloc, data, N, guess, upper, itemnames, exploratory, parprior,
-                           parnumber, BFACTOR = FALSE, mixed.design, customItems, dentype,
-                           customGroup, key, gpcm_mats, spline_args, monopoly.k, dcIRT_nphi = NULL)
+                           parnumber, BFACTOR = FALSE, mixed.design, customItems, customItemsData,
+                           dentype, item.Q, customGroup, key, gpcm_mats, spline_args,
+                           monopoly.k, dcIRT_nphi = NULL)
 {
     hasProdTerms <- ifelse(nfact == nfactNames, FALSE, TRUE)
     prodlist <- NULL
@@ -108,10 +109,34 @@ model.elements <- function(model, factorNames, itemtype, nfactNames, nfact, J, K
     if(exploratory && any(itemtype %in% c('PC2PL', 'PC3PL')))
         stop('Partially compensatory models can only be estimated within a confirmatory model',
              call.=FALSE)
+    if(is.null(item.Q) && any(itemtype == 'lca')){
+        item.Q <- vector('list', J)
+        for(i in seq_len(J)){
+            item.Q[[i]] <- matrix(1, K[i], nfact)
+            item.Q[[i]][1L, ] <- 0
+        }
+    }
+    if(!is.null(item.Q)){
+        if(length(item.Q) != J)
+            stop('item.Q list does not have the correct length', call.=FALSE)
+        for(i in seq_len(J)){
+            if(is.null(item.Q[[i]])){
+                item.Q[[i]] <- matrix(1, K[i], nfact)
+                item.Q[[i]][1L, ] <- 0
+            }
+        }
+        tmptest <- sapply(item.Q, nrow) == K & sapply(item.Q, ncol) == nfact & sapply(item.Q, is.matrix)
+        if(!all(tmptest))
+            stop(sprintf("item.Q list has incorrect matrix structures for the following item(s): %s",
+                         paste0(which(!tmptest), collapse=', ')), call.=FALSE)
+        if(any(sapply(item.Q, function(x) all(x[1L,] != 0))))
+            stop('The first row of ever item.Q matrix must consist only of 0\'s for proper identification',
+                 call.=FALSE)
+    }
     ret <- LoadPars(itemtype=itemtype, itemloc=itemloc, lambdas=lambdas, zetas=zetas,
-                    guess=guess, upper=upper, fulldata=fulldata, J=J, K=K,
+                    guess=guess, upper=upper, fulldata=fulldata, J=J, K=K, customItemsData=customItemsData,
                     nfact=nfact+length(prodlist), parprior=parprior, monopoly.k=monopoly.k,
-                    parnumber=parnumber, estLambdas=estlam, BFACTOR=BFACTOR,
+                    parnumber=parnumber, estLambdas=estlam, BFACTOR=BFACTOR, item.Q=item.Q,
                     mixed.design=mixed.design, customItems=customItems, key=key,
                     gpcm_mats=gpcm_mats, spline_args=spline_args, itemnames=itemnames)
     ret[[length(ret) + 1L]] <- LoadGroupPars(gmeans=gmeans, gcov=gcov, estgmeans=estgmeans,
